cosmpy.protos.cosmos.crypto.multisig package — cosmpy documentation

# cosmpy.protos.cosmos.crypto.multisig package

## Subpackages

- cosmpy.protos.cosmos.crypto.multisig.v1beta1 package
  - Submodules
  - cosmpy.protos.cosmos.crypto.multisig.v1beta1.multisig_pb2 module
  - cosmpy.protos.cosmos.crypto.multisig.v1beta1.multisig_pb2_grpc module
  - Module contents

## Submodules

## cosmpy.protos.cosmos.crypto.multisig.keys_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.crypto.multisig.keys_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents